@@ -652,13 +652,13 @@ def new_application(dhurl, cookies, appname, appversion, appautoinc, envs):
         parts = appversion.split(';')
         ver = parts.pop()
         if ('_' in ver):
-            parts = ver.split('_')
-            incnum = parts.pop()
-            incnum = incnum + 1
-            parts.push(incnum)
-            ver = '_'.join(parts)
+            schema_parts = ver.split('_')
+            incnum = schema_parts.pop()
+            incnum = str(int(incnum) + 1)
+            schema_parts.push(incnum)
+            ver = '_'.join(schema_parts)
         elif (ver.isdigit()):
-            ver = ver + 1
+            ver = str(int(ver) + 1)
         else:
             ver = ver + ";1"
         parts.push(ver)
